@@ -874,16 +874,23 @@ gst_base_transform_default_decide_allocation (GstBaseTransform * trans,
       /* If change are not acceptable, fallback to generic pool */
       if (!gst_buffer_pool_config_validate_params (config, outcaps, size, min,
               max)) {
-        GST_DEBUG_OBJECT (trans, "unsupported pool, making new pool");
-
-        gst_object_unref (pool);
-        pool = gst_buffer_pool_new ();
-        gst_buffer_pool_config_set_params (config, outcaps, size, min, max);
-        gst_buffer_pool_config_set_allocator (config, allocator, &params);
+        gst_structure_free (config);
+        gst_clear_object (&pool);
+      } else if (!gst_buffer_pool_set_config (pool, config)) {
+        gst_clear_object (&pool);
       }
 
-      if (!gst_buffer_pool_set_config (pool, config))
-        goto config_failed;
+      if (!pool) {
+        GST_DEBUG_OBJECT (trans, "unsupported pool, making new pool");
+
+        pool = gst_buffer_pool_new ();
+        config = gst_buffer_pool_get_config (pool);
+        gst_buffer_pool_config_set_params (config, outcaps, size, min, max);
+        gst_buffer_pool_config_set_allocator (config, allocator, &params);
+
+        if (!gst_buffer_pool_set_config (pool, config))
+          goto config_failed;
+      }
     }
   }
 
